@@ -17,9 +17,9 @@ It provides :meth:`Box3D.iou` to calculate the intersection over union of two 3D
 
 import math
 import warnings
-from typing import Dict, Iterable, Tuple, Type, TypeVar
+from typing import Dict, Iterable, Optional, Tuple, Type, TypeVar
 
-from ..utility import ReprMixin, ReprType, UserSequence, common_loads
+from ..utility import MatrixType, ReprMixin, ReprType, UserSequence, common_loads
 from .transform import Transform3D
 from .vector import Vector2D, Vector3D
 
@@ -45,6 +45,10 @@ class Box2D(UserSequence[float]):
         xmax: The x coordinate of the bottom-right vertex of the 2D box.
         ymax: The y coordinate of the bottom-right vertex of the 2D box.
 
+    Examples:
+        >>> Box2D(1, 2, 3, 4)
+        Box2D(1, 2, 3, 4)
+
     """
 
     _repr_type = ReprType.INSTANCE
@@ -82,11 +86,14 @@ class Box2D(UserSequence[float]):
             The intersect box of the two boxes.
 
         """
-        xmin = max(self._data[0], other._data[0])
-        ymin = max(self._data[1], other._data[1])
-        xmax = min(self._data[2], other._data[2])
-        ymax = min(self._data[3], other._data[3])
-        return Box2D(xmin, ymin, xmax, ymax)
+        try:
+            xmin = max(self._data[0], other._data[0])
+            ymin = max(self._data[1], other._data[1])
+            xmax = min(self._data[2], other._data[2])
+            ymax = min(self._data[3], other._data[3])
+            return Box2D(xmin, ymin, xmax, ymax)
+        except (TypeError, IndexError, AttributeError):
+            return NotImplemented
 
     def _loads(self, contents: Dict[str, float]) -> None:
         self._data = (contents["xmin"], contents["ymin"], contents["xmax"], contents["ymax"])
@@ -111,6 +118,12 @@ class Box2D(UserSequence[float]):
         Returns:
             The intersection over union between the two input boxes.
 
+        Examples:
+            >>> box2d_1 = Box2D(1, 2, 3, 4)
+            >>> box2d_2 = Box2D(2, 2, 3, 4)
+            >>> Box2D.iou(box2d_1, box2d_2)
+            0.5
+
         """
         area1 = box1.area()
         area2 = box2.area()
@@ -132,6 +145,10 @@ class Box2D(UserSequence[float]):
         Returns:
             The created :class:`Box2D` instance.
 
+        Examples:
+            >>> Box2D.from_xywh(1, 2, 3, 4)
+            Box2D(1, 2, 4, 6)
+
         """
         return cls(x, y, x + width, y + height)
 
@@ -140,18 +157,16 @@ class Box2D(UserSequence[float]):
         """Load a :class:`Box2D` from a dict containing coordinates of the 2D box.
 
         Arguments:
-            contents: A dict containing coordinates of a 2D box::
-
-                {
-                    "xmin": ...
-                    "ymin": ...
-                    "xmax": ...
-                    "ymax": ...
-                }
+            contents: A dict containing coordinates of a 2D box.
 
         Returns:
             The loaded :class:`Box2D` object.
 
+        Examples:
+            >>> contents = {"xmin": 1.0, "ymin": 2.0, "xmax": 3.0, "ymax": 4.0}
+            >>> Box2D.loads(contents)
+            Box2D(1.0, 2.0, 3.0, 4.0)
+
         """
         return common_loads(cls, contents)
 
@@ -162,6 +177,11 @@ class Box2D(UserSequence[float]):
         Returns:
             Minimum x coordinate.
 
+        Examples:
+            >>> box2d = Box2D(1, 2, 3, 4)
+            >>> box2d.xmin
+            1
+
         """
         return self._data[0]
 
@@ -172,6 +192,11 @@ class Box2D(UserSequence[float]):
         Returns:
             Minimum y coordinate.
 
+        Examples:
+            >>> box2d = Box2D(1, 2, 3, 4)
+            >>> box2d.ymin
+            2
+
         """
         return self._data[1]
 
@@ -182,6 +207,11 @@ class Box2D(UserSequence[float]):
         Returns:
             Maximum x coordinate.
 
+        Examples:
+            >>> box2d = Box2D(1, 2, 3, 4)
+            >>> box2d.xmax
+            3
+
         """
         return self._data[2]
 
@@ -192,6 +222,11 @@ class Box2D(UserSequence[float]):
         Returns:
             Maximum y coordinate.
 
+        Examples:
+            >>> box2d = Box2D(1, 2, 3, 4)
+            >>> box2d.ymax
+            4
+
         """
         return self._data[3]
 
@@ -202,6 +237,11 @@ class Box2D(UserSequence[float]):
         Returns:
             The top left point.
 
+        Examples:
+            >>> box2d = Box2D(1, 2, 3, 4)
+            >>> box2d.tl
+            Vector2D(1, 2)
+
         """
         return Vector2D(self._data[0], self._data[1])
 
@@ -212,6 +252,11 @@ class Box2D(UserSequence[float]):
         Returns:
             The bottom right point.
 
+        Examples:
+            >>> box2d = Box2D(1, 2, 3, 4)
+            >>> box2d.br
+            Vector2D(3, 4)
+
         """
         return Vector2D(self._data[2], self._data[3])
 
@@ -222,6 +267,11 @@ class Box2D(UserSequence[float]):
         Returns:
             The width of the 2D box.
 
+        Examples:
+            >>> box2d = Box2D(1, 2, 3, 6)
+            >>> box2d.width
+            2
+
         """
         return self._data[2] - self._data[0]
 
@@ -232,6 +282,11 @@ class Box2D(UserSequence[float]):
         Returns:
             The height of the 2D box.
 
+        Examples:
+            >>> box2d = Box2D(1, 2, 3, 6)
+            >>> box2d.height
+            4
+
         """
         return self._data[3] - self._data[1]
 
@@ -241,6 +296,11 @@ class Box2D(UserSequence[float]):
         Returns:
             A dict containing vertex coordinates of the box.
 
+        Examples:
+            >>> box2d = Box2D(1, 2, 3, 4)
+            >>> box2d.dumps()
+            {'xmin': 1, 'ymin': 2, 'xmax': 3, 'ymax': 4}
+
         """
         return {
             "xmin": self._data[0],
@@ -255,6 +315,11 @@ class Box2D(UserSequence[float]):
         Returns:
             The area of the 2D box.
 
+        Examples:
+            >>> box2d = Box2D(1, 2, 3, 4)
+            >>> box2d.area()
+            4
+
         """
         return self.width * self.height
 
@@ -267,27 +332,46 @@ class Box3D(ReprMixin):
     It provides :meth:`Box3D.iou` to calculate the intersection over union of two 3D boxes.
 
     Arguments:
-        transform: A :class:`~tensorbay.geometry.transform.Transform3D` object
-            or a 4x4 or 3x4 transform matrix.
         translation: Translation in a sequence of [x, y, z].
-        rotation: Rotation in a sequence of [w, x, y, z] or a 3x3 rotation matrix
-            or a numpy quaternion object.
+        rotation: Rotation in a sequence of [w, x, y, z] or numpy quaternion.
         size: Size in a sequence of [x, y, z].
+        transform_matrix: A 4x4 or 3x4 transform matrix.
+
+    Examples:
+        *Initialization Method 1:* Init from size, translation and rotation.
+
+        >>> Box3D([1, 2, 3], [0, 1, 0, 0], [1, 2, 3])
+        Box3D(
+          (size): Vector3D(1, 2, 3)
+          (translation): Vector3D(1, 2, 3),
+          (rotation): quaternion(0, 1, 0, 0),
+        )
+
+        *Initialization Method 2:* Init from size and transform matrix.
+
+        >>> from tensorbay.geometry import Transform3D
+        >>> matrix = [[1, 0, 0, 1], [0, 1, 0, 2], [0, 0, 1, 3]]
+        >>> Box3D(size=[1, 2, 3], transform_matrix=matrix)
+        Box3D(
+          (size): Vector3D(1, 2, 3)
+          (translation): Vector3D(1, 2, 3),
+          (rotation): quaternion(1, -0, -0, -0),
+        )
 
     """
 
     _repr_type = ReprType.INSTANCE
-    _repr_attrs: Tuple[str, ...] = ("translation", "rotation", "size")
+    _repr_attrs: Tuple[str, ...] = ("size", "translation", "rotation")
 
     def __init__(
         self,
-        transform: Transform3D.TransformType = None,
-        *,
+        size: Iterable[float],
         translation: Iterable[float] = (0, 0, 0),
         rotation: Transform3D.RotationType = (1, 0, 0, 0),
-        size: Iterable[float] = (0, 0, 0),
+        *,
+        transform_matrix: Optional[MatrixType] = None,
     ) -> None:
-        self._transform = Transform3D(transform, translation=translation, rotation=rotation)
+        self._transform = Transform3D(translation, rotation, matrix=transform_matrix)
         self._size = Vector3D(*size)
 
     def __eq__(self, other: object) -> bool:
@@ -317,6 +401,10 @@ class Box3D(ReprMixin):
         Returns:
             The intersect length between line1 and line2.
 
+        Examples:
+            >>> Box3D._line_intersect(4, 4, 1)
+            3.0
+
         """
         line1_min = -length1 / 2
         line1_max = length1 / 2
@@ -334,30 +422,24 @@ class Box3D(ReprMixin):
         """Load a :class:`Box3D` from a dict containing the coordinates of the 3D box.
 
         Arguments:
-            contents: A dict containing the coordinates of a 3D box::
-
-                {
-                    "size": {
-                        "x": ...
-                        "y": ...
-                        "z": ...
-                    },
-                    "translation": {
-                        "x": ...
-                        "y": ...
-                        "z": ...
-                    },
-                    "rotation": {
-                        "w": ...
-                        "x": ...
-                        "y": ...
-                        "z": ...
-                    }
-                }
+            contents: A dict containing the coordinates of a 3D box.
 
         Returns:
             The loaded :class:`Box3D` object.
 
+        Examples:
+            >>> contents = {
+            ...     "size": {"x": 1.0, "y": 2.0, "z": 3.0},
+            ...     "translation": {"x": 1.0, "y": 2.0, "z": 3.0},
+            ...     "rotation": {"w": 0.0, "x": 1.0, "y": 0.0, "z": 0.0},
+            ... }
+            >>> Box3D.loads(contents)
+            Box3D(
+              (size): Vector3D(1.0, 2.0, 3.0)
+              (translation): Vector3D(1.0, 2.0, 3.0),
+              (rotation): quaternion(0, 1, 0, 0),
+            )
+
         """
         return common_loads(cls, contents)
 
@@ -374,6 +456,12 @@ class Box3D(ReprMixin):
         Returns:
             The intersection over union of the two 3D boxes.
 
+        Examples:
+            >>> box3d_1 = Box3D(size=[1, 1, 1])
+            >>> box3d_2 = Box3D(size=[2, 2, 2])
+            >>> Box3D.iou(box3d_1, box3d_2)
+            0.125
+
         """
         box2 = box1.transform.inverse() * box2
         if abs(math.degrees(box2.rotation.angle())) > angle_threshold:
@@ -393,6 +481,11 @@ class Box3D(ReprMixin):
         Returns:
             The translation of the 3D box.
 
+        Examples:
+            >>> box3d = Box3D(size=(1, 1, 1), translation=(1, 2, 3))
+            >>> box3d.translation
+            Vector3D(1, 2, 3)
+
         """
         return self._transform.translation
 
@@ -403,6 +496,11 @@ class Box3D(ReprMixin):
         Returns:
             The rotation of the 3D box.
 
+        Examples:
+            >>> box3d = Box3D(size=(1, 1, 1), rotation=(0, 1, 0, 0))
+            >>> box3d.rotation
+            quaternion(0, 1, 0, 0)
+
         """
         return self._transform.rotation
 
@@ -413,6 +511,14 @@ class Box3D(ReprMixin):
         Returns:
             The transform of the 3D box.
 
+        Examples:
+            >>> box3d = Box3D(size=(1, 1, 1), translation=(1, 2, 3), rotation=(1, 0, 0, 0))
+            >>> box3d.transform
+            Transform3D(
+              (translation): Vector3D(1, 2, 3),
+              (rotation): quaternion(1, 0, 0, 0)
+            )
+
         """
         return self._transform
 
@@ -423,6 +529,11 @@ class Box3D(ReprMixin):
         Returns:
             The size of the 3D box.
 
+        Examples:
+            >>> box3d = Box3D(size=(1, 1, 1))
+            >>> box3d.size
+            Vector3D(1, 1, 1)
+
         """
         return self._size
 
@@ -432,6 +543,11 @@ class Box3D(ReprMixin):
         Returns:
             The volume of the 3D box.
 
+        Examples:
+            >>> box3d = Box3D(size=(1, 2, 3))
+            >>> box3d.volume()
+            6
+
         """
         return self.size.x * self.size.y * self.size.z
 
@@ -441,6 +557,15 @@ class Box3D(ReprMixin):
         Returns:
             A dict containing translation, rotation and size information.
 
+        Examples:
+            >>> box3d = Box3D(size=(1, 2, 3), translation=(1, 2, 3), rotation=(0, 1, 0, 0))
+            >>> box3d.dumps()
+            {
+                "translation": {"x": 1, "y": 2, "z": 3},
+                "rotation": {"w": 0.0, "x": 1.0, "y": 0.0, "z": 0.0},
+                "size": {"x": 1, "y": 2, "z": 3},
+            }
+
         """
         contents = self._transform.dumps()
         contents["size"] = self.size.dumps()
